@@ -4,44 +4,42 @@ data_location = os.path.join(__dir__, "verilog")
 src = "https://github.com/openrisc/mor1kx.git"
 
 # Module version
-version_str = "5.0.post136"
-version_tuple = (5, 0, 136)
+version_str = "5.1.1.post142"
+version_tuple = (5, 1, 1, 142)
 try:
     from packaging.version import Version as V
-    pversion = V("5.0.post136")
+    pversion = V("5.1.1.post142")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "5.0.post76"
-data_version_tuple = (5, 0, 76)
+data_version_str = "5.1.1.post0"
+data_version_tuple = (5, 1, 1, 0)
 try:
     from packaging.version import Version as V
-    pdata_version = V("5.0.post76")
+    pdata_version = V("5.1.1.post0")
 except ImportError:
     pass
-data_git_hash = "06e2e46afbad62572c31bde88e8f2424e23ecda2"
-data_git_describe = "v5.0-76-g06e2e46"
+data_git_hash = "4cebbb684bba8f9fe74f9b69e679796d4fd4a35b"
+data_git_describe = "v5.1.1-0-g4cebbb6"
 data_git_msg = """\
-commit 06e2e46afbad62572c31bde88e8f2424e23ecda2
-Author: JaewonHur <57657645+JaewonHur@users.noreply.github.com>
-Date:   Mon Dec 23 01:23:20 2019 +0900
+commit 4cebbb684bba8f9fe74f9b69e679796d4fd4a35b
+Merge: 44ea698 1a8c19b
+Author: Stafford Horne <shorne@gmail.com>
+Date:   Mon May 23 06:01:28 2022 +0900
 
-    Fix mor1kx_decode to accept valid l.fl1 (l.ff1) instructions (#110)
+    Merge pull request #147 from stffrdhrn/or1k-linux-failing
     
-    * Fix mor1kx_decode to only accept valid l.fl1 and l.ff1 instructions
-    
-    Both l.fl1 and l.ff1 have bit 9 set in the insruction as port of their op codes,
-    mor1kx_decode does not currently properly check this
+    Revert "dcache: Allow writing during write_pending"
 
 """
 
 # Tool version info
-tool_version_str = "0.0.post60"
-tool_version_tuple = (0, 0, 60)
+tool_version_str = "0.0.post142"
+tool_version_tuple = (0, 0, 142)
 try:
     from packaging.version import Version as V
-    ptool_version = V("0.0.post60")
+    ptool_version = V("0.0.post142")
 except ImportError:
     pass
 
